@@ -79,9 +79,9 @@ if(model %in% c(1,9,34,12,20,18,39,27,38,29,21,26,24,10,22,40,28,33,42))
             if(model==1) fname <- "CorrelationMat_biv_dyn2"
             if(model==10)fname <- "CorrelationMat_biv_skew_dyn2" }
      
-corr=double(numpairstot)
+#corr=double(numpairstot)
 cr=dotCall64::.C64(fname,SIGNATURE = c("double","double","double","double",  "integer","double","double","double","integer","integer"),
-    corr=corr,coordx,coordy,coordt,corrmodel,nuisance,paramcorr,radius,ns,NS,
+    corr=dotCall64::numeric_dc(numpairstot),coordx,coordy,coordt,corrmodel,nuisance,paramcorr,radius,ns,NS,
  INTENT = c("w","r","r","r","r","r","r","r", "r", "r"),
             PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)
       }
@@ -90,12 +90,12 @@ cr=dotCall64::.C64(fname,SIGNATURE = c("double","double","double","double",  "in
         fname <- "CorrelationMat_tap"
         if(spacetime) fname <- "CorrelationMat_st_tap"
        if(bivariate) fname <- "CorrelationMat_biv_tap"
-       corr=double(numpairs)
+       #corr=double(numpairs)
         #cr=.C(fname,  corr=corr, as.double(coordx),as.double(coordy),as.double(coordt),
         #  as.integer(corrmodel), as.double(nuisance), as.double(paramcorr),as.double(radius),as.integer(ns),
         #   as.integer(NS),PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
 cr=dotCall64::.C64(fname,SIGNATURE = c("double","double","double","double",  "integer","double","double","double","integer","integer"),
-     corr=corr, coordx,coordy,coordt,corrmodel,nuisance, paramcorr,radius,ns,NS,
+     corr=dotCall64::numeric_dc(numpairs), coordx,coordy,coordt,corrmodel,nuisance, paramcorr,radius,ns,NS,
   INTENT = c("w","r","r","r","r","r","r","r", "r", "r"),
              PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)
      ## deleting correlation equual  to 1 because there are problems  with hipergeometric function
@@ -568,6 +568,7 @@ if(model==22)  {  ## Log Gaussian
           diag(varcov)=1
         }
     V=vv%*%t(vv)
+   
     varcov=varcov*sqrt(V)
 }
 
@@ -586,30 +587,26 @@ if(!bivariate){
             mu=ML
 
 if(type=="Standard")  {
-  corr=double(numpairstot)
+  #corr=double(numpairstot)
 
     fname <-"CorrelationMat_dis2"
     if(spacetime) fname <- "CorrelationMat_st_dyn_dis2"
 
-   if(spacetime)
-              cr=.C("CorrelationMat_st_dyn_dis2", corr=corr,  as.double(coordx),as.double(coordy),as.double(coordt),
-              as.integer(corrmodel), as.double(c(mu)),as.integer(n), as.double(other_nuis), as.double(paramcorr),as.double(radius),
-              as.integer(ns), as.integer(NS),as.integer(model),
-              PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
+    #          cr=.C(fname, corr=corr,  as.double(coordx),as.double(coordy),as.double(coordt),
+    #          as.integer(corrmodel), as.double(c(mu)),as.integer(n), as.double(other_nuis), as.double(paramcorr),as.double(radius),
+    #          as.integer(ns), as.integer(NS),as.integer(model),
+    #          PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
+
+  cr=dotCall64::.C64(fname,SIGNATURE =
+      c("double","double","double","double", 
+       "integer","double","integer","double",
+       "double","double","integer","integer","integer"),
+        corr=dotCall64::numeric_dc(numpairstot), coordx,coordy,coordt,corrmodel,c(mu), n,other_nuis,paramcorr,radius,ns,NS,model,
+  INTENT = c("w","r","r","r","r","r","r","r", "r", "r","r", "r", "r"),
+             PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)
 
-    if(!spacetime)
-       cr=.C("CorrelationMat_dis2", corr=corr,  as.double(coordx),as.double(coordy),as.double(coordt),
-              as.integer(corrmodel), as.double(c(mu)),as.integer(n), as.double(other_nuis), as.double(paramcorr),as.double(radius),
-              as.integer(ns), as.integer(NS),as.integer(model),
-              PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
-  #cr=dotCall64::.C64(fname,SIGNATURE =
-   #    c("double","double","double","double",  "integer","double","integer","double","double","double","integer","integer","integer"),
-   #     corr=corr, coordx,coordy,coordt,corrmodel,c(mu), min(n),other_nuis,paramcorr,radius,ns,NS,model,
-  #INTENT = c("w","r","r","r","r","r","r","r", "r", "r","r", "r", "r"),
-   #          PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)
      corr=cr$corr # ojo que corr en este caso es una covarianza y ya va con el nugget
 
-
      varcov <-  diag(dime)
      varcov[lower.tri(varcov)] <- corr
      varcov <- t(varcov)
@@ -625,22 +622,22 @@ if(type=="Standard")  {
 
         fname <- "CorrelationMat_dis_tap"
         if(spacetime) fname <- "CorrelationMat_st_dis_tap"
-         corr=double(numpairs)
+      #   corr=double(numpairs)
 
- if(spacetime)
-        cr=.C("CorrelationMat_st_dis_tap",  corr=corr, as.double(coordx),as.double(coordy),as.double(coordt),
-        as.integer(corrmodel), as.double(other_nuis), as.double(paramcorr),as.double(radius),as.integer(ns),
-           as.integer(NS),as.integer(n[idx[,1]]),as.integer(n[idx[,2]]),as.double(mu[idx[,1]]),as.double(mu[idx[,2]]),as.integer(model),PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
- else
-              cr=.C("CorrelationMat_dis_tap",  corr=corr, as.double(coordx),as.double(coordy),as.double(coordt),
-        as.integer(corrmodel), as.double(other_nuis), as.double(paramcorr),as.double(radius),as.integer(ns),
-           as.integer(NS),as.integer(n[idx[,1]]),as.integer(n[idx[,2]]),as.double(mu[idx[,1]]),as.double(mu[idx[,2]]),as.integer(model),PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
+ #if(spacetime)
+    #    cr=.C(fname,  corr=corr, as.double(coordx),as.double(coordy),as.double(coordt),
+    #    as.integer(corrmodel), as.double(other_nuis), as.double(paramcorr),as.double(radius),as.integer(ns),
+    #       as.integer(NS),as.integer(n[idx[,1]]),as.integer(n[idx[,2]]),as.double(mu[idx[,1]]),as.double(mu[idx[,2]]),as.integer(model),PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
+# else
+ #             cr=.C("CorrelationMat_dis_tap",  corr=corr, as.double(coordx),as.double(coordy),as.double(coordt),
+  #      as.integer(corrmodel), as.double(other_nuis), as.double(paramcorr),as.double(radius),as.integer(ns),
+   #        as.integer(NS),as.integer(n[idx[,1]]),as.integer(n[idx[,2]]),as.double(mu[idx[,1]]),as.double(mu[idx[,2]]),as.integer(model),PACKAGE='GeoModels', DUP=TRUE, NAOK=TRUE)
  
-#      cr=dotCall64::.C64(fname,SIGNATURE =
-#         c("double","double","double","double","integer","double","double","double","integer","integer","integer","double","double","integer"),
-#        corr=corr, coordx,coordy,coordt,corrmodel,other_nuis,paramcorr,radius,ns,NS,min(n),mu[idx[,1]],mu[idx[,2]],model,
-#  INTENT = c("w","r","r","r","r","r","r","r", "r", "r","r", "r", "r", "r"),
-#             PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)
+     cr=dotCall64::.C64(fname,SIGNATURE =
+         c("double","double","double","double","integer","double","double","double","integer","integer","integer","integer","double","double","integer"),
+        corr=dotCall64::numeric_dc(numpairs), coordx,coordy,coordt,corrmodel,other_nuis,paramcorr,radius,ns,NS,n[idx[,1]],n[idx[,2]],mu[idx[,1]],mu[idx[,2]],model,
+  INTENT = c("w","r","r","r","r","r","r","r", "r", "r","r", "r", "r", "r","r"),
+             PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)
 
 
         varcov <-new("spam",entries=cr$corr,colindices=setup$ja,
@@ -811,23 +808,22 @@ else                    param$sill=1
     #######################
 
       if(initparam$spacetime) fname= "CorrelationMat_st_tap"
+      else {
       if(!initparam$spacetime) fname= "CorrelationMat_tap"
       if(initparam$bivariate) fname= "CorrelationMat_biv_tap"
+     }
 
-if(initparam$spacetime) 
-    {tp=.C("CorrelationMat_st_tap",tapcorr=double(initparam$numpairs),as.double(cc[,1]),as.double(cc[,2]),as.double(initparam$coordt),as.integer(tapmod),
-      as.double(1),as.double(tapsep),as.double(1),0,0,
-      PACKAGE='GeoModels',DUP=TRUE,NAOK=TRUE) }
-    else {
- if(!initparam$bivariate) 
-     tp=.C("CorrelationMat_tap",tapcorr=double(initparam$numpairs),as.double(cc[,1]),as.double(cc[,2]),as.double(initparam$coordt),as.integer(tapmod),
-      as.double(1),as.double(tapsep),as.double(1),0,0,
-      PACKAGE='GeoModels',DUP=TRUE,NAOK=TRUE)
-else 
-      tp=.C("CorrelationMat_biv_tap",tapcorr=double(initparam$numpairs),as.double(cc[,1]),as.double(cc[,2]),as.double(initparam$coordt),as.integer(tapmod),
-      as.double(1),as.double(tapsep),as.double(1),0,0,
-      PACKAGE='GeoModels',DUP=TRUE,NAOK=TRUE)
-  }
+ #tp=.C(fname,tapcorr=double(initparam$numpairs),as.double(cc[,1]),as.double(cc[,2]),as.double(initparam$coordt),as.integer(tapmod),
+  #    as.double(1),as.double(tapsep),as.double(1),0,0,
+   #   PACKAGE='GeoModels',DUP=TRUE,NAOK=TRUE) 
+
+if(is.null(tapsep)) tapsep=1
+      tp=dotCall64::.C64(fname,SIGNATURE =
+         c("double","double","double","double","integer","double","double","double","integer","integer"),
+        tapcorr=dotCall64::numeric_dc(initparam$numpairs),
+        cc[,1],cc[,2],initparam$coordt,tapmod, 1,tapsep,1,1,1,
+  INTENT = c("w","r","r","r","r","r","r","r", "r", "r"),
+             PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)
 
         setup$taps<-tp$tapcorr
     }
@@ -855,7 +851,7 @@ if(!bivariate){
 if(model %in% c("Weibull","Poisson","Binomial","Gamma","LogLogistic",
         "BinomialNeg","Bernoulli","Geometric","Gaussian_misp_Poisson",
         'PoissonZIP','Gaussian_misp_PoissonZIP','BinomialNegZINB', 'PoissonGammaZIP','PoissonGammaZIP1','PoissonGamma',
-        'PoissonZIP1','Gaussian_misp_PoissonZIP1','BinomialNegZINB1',
+        'PoissonZIP1','Gaussian_misp_PoissonZIP1','BinomialNegZINB1',"LogGaussian",
         'Beta2','Kumaraswamy2','Beta','Kumaraswamy')) 
 {
 
@@ -894,6 +890,7 @@ else     { if(sum(sel)>1)                  ML=beta
     if(initparam$bivariate)   initparam$numtime=2
     if(!initparam$bivariate){namesnuis = NuisParam(model, bivariate,ncol(initparam$X),copula)}
     else                    {namesnuis =initparam$namesnuis}
+
 #######################################
     # Return the objects list:
     CovMat <- list(bivariate =  initparam$bivariate,
