@@ -15,6 +15,8 @@ GeoFit <- function(data, coordx, coordy=NULL, coordt=NULL, coordx_dyn=NULL,copul
 ###########  first preliminary check  ###############
     call <- match.call()
 
+    if(is.null(start)) stop("Starting parameters are missing")
+
     if(is.null(corrmodel)&& likelihood=="Marginal"&&type=="Independence") 
     {
         if(is.null(coordt)){corrmodel="Exponential";tlist=list(nugget=0,scale=1)}
@@ -74,6 +76,9 @@ if(!is.null(spobj)) {
      }
    if(!is.null(a$Y)&&!is.null(a$X)) {data=a$Y ; X=a$X }
 }
+###### setting nugget if missing
+if(!bivariate)
+   if(!sum(names(unlist(append(start,fixed)))=="nugget")) fixed$nugget=0
 ###############################################################
 ###############################################################  
 if(!bivariate){
@@ -227,6 +232,7 @@ if(!is.null(anisopars)) {
     }
     ###################################################################################
     ###################################################################################
+
    # Full likelihood:
     if(likelihood=='Full')
           # Fitting by log-likelihood maximization:
