@@ -91,19 +91,19 @@ GeoVariogram <- function(data, coordx, coordy=NULL, coordt=NULL, coordx_dyn=NULL
                moments_cross<-double(0.5*n_var*(n_var-1)*numvario)  # vect of square differences for cross components (12)
                lenbins_cross<-integer(0.5*n_var*(n_var-1)*numvario) #
 
-               DEV=.C("Binned_Variogram_biv2", bins=bins, as.double(coordx),as.double(coordy),as.double(coordt),as.double(data),
-               lenbins_cross=lenbins_cross, moments_cross=moments_cross, as.integer(numbins),lenbins_marg=lenbins_marg,
-               moments_marg=moments_marg,as.integer(ns),as.integer(NS),
-               PACKAGE='GeoModels', DUP = TRUE, NAOK=TRUE)
+             #  DEV=.C("Binned_Variogram_biv2", bins=bins, as.double(coordx),as.double(coordy),as.double(coordt),as.double(data),# 5
+             #  lenbins_cross=lenbins_cross, moments_cross=moments_cross, as.integer(numbins),lenbins_marg=lenbins_marg,         # 4
+             #  moments_marg=moments_marg,as.integer(ns),as.integer(NS),                                                         # 3
+             #  PACKAGE='GeoModels', DUP = TRUE, NAOK=TRUE)
                
-              #DEV=dotCall64::.C64("Binned_Variogram_biv2", 
-               #      SIGNATURE = c("double","double","double","double","double",
-                #                "integer","double","integer","integer",
-                    #            "double","integer","integer"),
-              #  bins=bins, coordx,coordy,coordt,data,
-              # lenbins_cross=lenbins_cross, moments_cross=moments_cross, numbins,lenbins_marg=lenbins_marg,
-              # moments_marg=moments_marg,ns,NS,
-                # INTENT = c("w","r","r","r","r","w","w","r","w","w","r","r"),NAOK = TRUE, PACKAGE = "GeoModels", VERBOSE = 0)
+              DEV=dotCall64::.C64("Binned_Variogram_biv2", 
+                     SIGNATURE = c("double","double","double","double","double",
+                              "integer","double","integer","integer","double","integer","integer"),
+               bins=bins, coordx,coordy,coordt,data,
+               lenbins_cross=lenbins_cross, moments_cross=moments_cross, numbins,lenbins_marg=lenbins_marg,
+               moments_marg=moments_marg,ns,NS,
+                 INTENT = c("rw","r","r","r","r","rw",
+                  "rw","rw","rw","rw","r","r"),NAOK = TRUE, PACKAGE = "GeoModels", VERBOSE = 0)
 
                bins=DEV$bins
                lenbins_cross=DEV$lenbins_cross
@@ -157,24 +157,28 @@ GeoVariogram <- function(data, coordx, coordy=NULL, coordt=NULL, coordx_dyn=NULL
       if(spacetime_dyn) fname <- paste(fname,"2_dyn",sep="") 
       if(!spacetime_dyn) fname <- paste(fname,"2",sep="") 
       # Compute the spatial-temporal moments:
-if(spacetime_dyn)
-      EV=.C("Binned_Variogram_st2_dyn", bins=bins, bint=bint,  as.double(coordx),as.double(coordy),as.double(coordt),as.double((data)),
+#if(spacetime_dyn)
+ #    EV=.C("Binned_Variogram_st2_dyn", bins=bins, bint=bint,  as.double(coordx),as.double(coordy),as.double(coordt),as.double(data),
+  #         lenbins=lenbins,lenbinst=lenbinst,lenbint=lenbint,moments=moments,momentst=momentst,momentt=momentt,
+   #        as.integer(numbins), as.integer(numbint),as.integer(ns),as.integer(NS), PACKAGE='GeoModels', DUP = TRUE, NAOK=TRUE)
+#if(!spacetime_dyn)
+ #     EV=.C("Binned_Variogram_st2", bins=bins, bint=bint,  as.double(coordx),as.double(coordy),as.double(coordt),as.double(data),
+  #         lenbins=lenbins,lenbinst=lenbinst,lenbint=lenbint,moments=moments,momentst=momentst,momentt=momentt,
+   #        as.integer(numbins), as.integer(numbint),as.integer(ns),as.integer(NS), PACKAGE='GeoModels', DUP = TRUE, NAOK=TRUE)
+
+    EV=dotCall64::.C64(fname, 
+                    SIGNATURE = c("double","double","double","double","double","double",
+                               "integer","integer","integer","double","double","double",
+                                "integer","integer","integer","integer"),
+               bins=bins, bint=bint,coordx,coordy,coordt,data,
            lenbins=lenbins,lenbinst=lenbinst,lenbint=lenbint,moments=moments,momentst=momentst,momentt=momentt,
-           as.integer(numbins), as.integer(numbint),as.integer(ns),as.integer(NS), PACKAGE='GeoModels', DUP = TRUE, NAOK=TRUE)
-if(!spacetime_dyn)
-      EV=.C("Binned_Variogram_st2", bins=bins, bint=bint,  as.double(coordx),as.double(coordy),as.double(coordt),as.double((data)),
-           lenbins=lenbins,lenbinst=lenbinst,lenbint=lenbint,moments=moments,momentst=momentst,momentt=momentt,
-           as.integer(numbins), as.integer(numbint),as.integer(ns),as.integer(NS), PACKAGE='GeoModels', DUP = TRUE, NAOK=TRUE)
+           numbins,numbint,ns,NS,
+                 INTENT = c("rw","rw","r","r","r","r",
+                            "rw","rw","rw","rw","rw","rw", 
+                            "r","r","r","r"), 
+                   NAOK = TRUE, PACKAGE = "GeoModels", VERBOSE = 0)
+
 
-    # EV=dotCall64::.C64(fname, 
-             #        SIGNATURE = c("double","double","double","double","double","double",
-            #                    "integer","integer","integer","double","double","double",
-           #                     "integer","integer","integer","integer"),
-          #     bins=bins, bint=bint,coordx,coordy,coordt,data,
-         #  lenbins=lenbins,lenbinst=lenbinst,lenbint=lenbint,moments=moments,momentst=momentst,momentt=momentt,
-        #   numbins,numbint,ns,NS,
-       #          INTENT = c("w","w","r","r","r","r","w","w","w","w","w","w", "r","r","r","r"), 
-      #             NAOK = TRUE, PACKAGE = "GeoModels", VERBOSE = 0)
        bins=EV$bins
        bint=EV$bint
        lenbins=EV$lenbins
@@ -333,7 +337,7 @@ if(x$bivariate)       bivariate=TRUE
      persp(c(0,x$centers), c(0,x$bint), evario,
       xlab="h", ylab="u", zlab=expression(gamma(h,u)),
       ltheta=90, shade=0.75, ticktype="detailed", phi=30,
-      theta=30,main="Space-time semi-variogram",cex.axis=.8,
+      theta=30,main="Smoothed space-time semi-variogram",cex.axis=.8,
       cex.lab=.8)
 
 
